@@ -56,8 +56,8 @@ SpeedLimitsDlg::SpeedLimitsDlg(bt::TorrentInterface *current, Core *core, QWidge
 
     m_upload_rate->setValue(Settings::maxUploadRate());
     m_download_rate->setValue(Settings::maxDownloadRate());
-    connect(m_upload_rate, qOverload<int>(&QSpinBox::valueChanged), this, &SpeedLimitsDlg::spinBoxValueChanged);
-    connect(m_download_rate, qOverload<int>(&QSpinBox::valueChanged), this, &SpeedLimitsDlg::spinBoxValueChanged);
+    connect(m_upload_rate, &QSpinBox::valueChanged, this, &SpeedLimitsDlg::spinBoxValueChanged);
+    connect(m_download_rate, &QSpinBox::valueChanged, this, &SpeedLimitsDlg::spinBoxValueChanged);
     connect(m_filter, &QLineEdit::textChanged, pm, &QSortFilterProxyModel::setFilterFixedString);
     loadState();
 
